@@ -2,11 +2,20 @@
 support for presenting detailed information in failing assertions.
 """
 import sys
+from typing import Any
+from typing import List
 from typing import Optional
 
 from _pytest.assertion import rewrite
 from _pytest.assertion import truncate
 from _pytest.assertion import util
+from _pytest.assertion.rewrite import assertstate_key
+from _pytest.compat import TYPE_CHECKING
+from _pytest.config import Config
+from _pytest.config import hookimpl
+
+if TYPE_CHECKING:
+    from _pytest.main import Session
 
 
 def pytest_addoption(parser):
@@ -77,13 +86,13 @@ class AssertionState:
 
 def install_importhook(config):
     """Try to install the rewrite hook, raise SystemError if it fails."""
-    config._assertstate = AssertionState(config, "rewrite")
-    config._assertstate.hook = hook = rewrite.AssertionRewritingHook(config)
+    config._store[assertstate_key] = AssertionState(config, "rewrite")
+    config._store[assertstate_key].hook = hook = rewrite.AssertionRewritingHook(config)
     sys.meta_path.insert(0, hook)
-    config._assertstate.trace("installed rewrite import hook")
+    config._store[assertstate_key].trace("installed rewrite import hook")
 
     def undo():
-        hook = config._assertstate.hook
+        hook = config._store[assertstate_key].hook
         if hook is not None and hook in sys.meta_path:
             sys.meta_path.remove(hook)
 
@@ -91,17 +100,18 @@ def install_importhook(config):
     return hook
 
 
-def pytest_collection(session):
+def pytest_collection(session: "Session") -> None:
     # this hook is only called when test modules are collected
     # so for example not in the master process of pytest-xdist
     # (which does not collect test modules)
-    assertstate = getattr(session.config, "_assertstate", None)
+    assertstate = session.config._store.get(assertstate_key, None)
     if assertstate:
         if assertstate.hook is not None:
             assertstate.hook.set_session(session)
 
 
-def pytest_runtest_setup(item):
+@hookimpl(tryfirst=True, hookwrapper=True)
+def pytest_runtest_protocol(item):
     """Setup the pytest_assertrepr_compare and pytest_assertion_pass hooks
 
     The newinterpret and rewrite modules will use util._reprcompare if
@@ -139,6 +149,7 @@ def pytest_runtest_setup(item):
                 return res
         return None
 
+    saved_assert_hooks = util._reprcompare, util._assertion_pass
     util._reprcompare = callbinrepr
 
     if item.ihook.pytest_assertion_pass.get_hookimpls():
@@ -150,18 +161,19 @@ def pytest_runtest_setup(item):
 
         util._assertion_pass = call_assertion_pass_hook
 
+    yield
 
-def pytest_runtest_teardown(item):
-    util._reprcompare = None
-    util._assertion_pass = None
+    util._reprcompare, util._assertion_pass = saved_assert_hooks
 
 
 def pytest_sessionfinish(session):
-    assertstate = getattr(session.config, "_assertstate", None)
+    assertstate = session.config._store.get(assertstate_key, None)
     if assertstate:
         if assertstate.hook is not None:
             assertstate.hook.set_session(None)
 
 
-def pytest_assertrepr_compare(config, op, left, right):
+def pytest_assertrepr_compare(
+    config: Config, op: str, left: Any, right: Any
+) -> Optional[List[str]]:
     return util.assertrepr_compare(config=config, op=op, left=left, right=right)
